from datetime import timedelta as D

days = D(days=1)
hours = D(hours=1)
minutes = D(minutes=1)
seconds = D(seconds=1)
milliseconds = D(milliseconds=1)
microseconds = D(microseconds=1)

__all__ = ['days', 'hours', 'minutes', 'seconds', 'milliseconds', 'microseconds']
__version__ = '0.0.3'
